@@ -72,7 +72,8 @@ int    get_dvd_r_rw_profile (const char *name);
 int    get_mmc_profile      (int fd);
 gint64 get_disc_size_cd     (int fd);
 int    get_disc_size_cdr    (int fd);
-gint64 get_disc_size_dvd    (int fd, int mmc_profile);
+gint64 get_disc_size_dvd    (int fd);
+gint64 get_disc_size_dvdr   (int fd, int mmc_profile);
 int    get_read_write_speed (int fd, int *read_speed, int *write_speed);
 int    get_disc_status      (int fd, int *empty, int *is_rewritable, int *is_blank);
 
@@ -96,10 +97,7 @@ static struct {
 	gboolean can_write_cdrw;
 	gboolean can_write_dvdr;
 	gboolean can_write_dvdram;
-} recorder_whitelist [] = {
-	{ "IOMEGA - CDRW9602EXT-B", TRUE, TRUE, FALSE, FALSE },
-	{ "SONY - CD-R   CDU948S",  TRUE, FALSE, FALSE, FALSE },
-};
+} recorder_whitelist [] = {};
 
 typedef enum {
 	NAUTILUS_BURN_DRIVE_PROTOCOL_IDE,
@@ -793,25 +791,22 @@ nautilus_burn_drive_get_media_type_from_path_full (const char *device,
 			int blank, rewrite, empty;
 
 			if (get_disc_status (fd, &empty, &rewrite, &blank) == 0) {
-				close_ioctl_handle (ioctl_handle);
 
 				if (is_rewritable)
 					*is_rewritable = rewrite;
+				
 				if (is_blank)
 					*is_blank = blank;
-
-				disc_type = get_disc_type (device);
-				disc_type_get_info (disc_type, is_blank, has_data, has_audio);
-
-				if (empty)
-					return NAUTILUS_BURN_MEDIA_TYPE_ERROR;
-				else
-					return NAUTILUS_BURN_MEDIA_TYPE_UNKNOWN;
 			}
-
 			close_ioctl_handle (ioctl_handle);
 
-			return NAUTILUS_BURN_MEDIA_TYPE_UNKNOWN;
+			disc_type = get_disc_type (device);
+			disc_type_get_info (disc_type, is_blank, has_data, has_audio);
+
+			if (empty)
+				return NAUTILUS_BURN_MEDIA_TYPE_ERROR;
+			else
+				return NAUTILUS_BURN_MEDIA_TYPE_UNKNOWN;
 		}
 	}
 
@@ -1111,6 +1106,9 @@ nautilus_burn_drive_get_media_size_from_path (const char *device)
 		else
 			size = 0;
 		break;
+	case 0x10:
+		size = get_disc_size_dvd (fd);
+		break;
 	case 0x11:
 	case 0x13:
 	case 0x14:
@@ -1118,7 +1116,7 @@ nautilus_burn_drive_get_media_size_from_path (const char *device)
 	case 0x2B:
 	case 0x1A:
 	case 0x12:
-		size = get_disc_size_dvd (fd, mmc_profile);
+		size = get_disc_size_dvdr (fd, mmc_profile);
 		break;
 	default:
 		size = NAUTILUS_BURN_MEDIA_SIZE_NA;
@@ -1171,25 +1169,25 @@ try_media_size_from_type (NautilusBurnDrive *drive)
 			size = 0;
 		break;
 	case NAUTILUS_BURN_MEDIA_TYPE_DVD:
-		size = get_disc_size_dvd (fd, 0x10);
+		size = get_disc_size_dvd (fd);
 		break;
 	case NAUTILUS_BURN_MEDIA_TYPE_DVDR:
-		size = get_disc_size_dvd (fd, 0x11);
+		size = get_disc_size_dvdr (fd, 0x11);
 		break;
 	case NAUTILUS_BURN_MEDIA_TYPE_DVDRW:
-		size = get_disc_size_dvd (fd, 0x13);
+		size = get_disc_size_dvdr (fd, 0x13);
 		break;
 	case NAUTILUS_BURN_MEDIA_TYPE_DVD_RAM:
-		size = get_disc_size_dvd (fd, 0x12);
+		size = get_disc_size_dvdr (fd, 0x12);
 		break;
 	case NAUTILUS_BURN_MEDIA_TYPE_DVD_PLUS_R:
-		size = get_disc_size_dvd (fd, 0x1B);
+		size = get_disc_size_dvdr (fd, 0x1B);
 		break;
 	case NAUTILUS_BURN_MEDIA_TYPE_DVD_PLUS_RW:
-		size = get_disc_size_dvd (fd, 0x1A);
+		size = get_disc_size_dvdr (fd, 0x1A);
 		break;
 	case NAUTILUS_BURN_MEDIA_TYPE_DVD_PLUS_R_DL:
-		size = get_disc_size_dvd (fd, 0x2B);
+		size = get_disc_size_dvdr (fd, 0x2B);
 		break;
 	default:
 		break;
