@@ -58,6 +58,19 @@ enum {
 	CANCEL_CD_RECORD,
 };
 
+enum {
+	NCB_SOURCE_BURN = 0,
+	NCB_SOURCE_IMAGE = 1,
+	NCB_SOURCE_DRIVE = 2,
+};
+
+enum {
+	NCB_OUTPUT_DEFAULT = 0,
+	NCB_OUTPUT_FILE = 1,
+	NCB_OUTPUT_CD = 2,
+	NCB_OUTPUT_DVD = 3,
+};
+
 typedef struct {
 	char              *source_device;
 	char              *source_iso;
@@ -1205,6 +1218,24 @@ write_disc (NautilusBurnerWriteData *data)
 	return res;
 }
 
+static int
+get_input_type_from_source_data (NautilusBurnerSourceData *burn_data)
+{
+	int input_type;
+
+	if (! burn_data) {
+		input_type = NCB_SOURCE_BURN;
+	} else if (burn_data->source_iso || burn_data->source_cue) {
+		input_type = NCB_SOURCE_IMAGE;
+	} else if (burn_data->source_drive || burn_data->source_device) {
+		input_type = NCB_SOURCE_DRIVE;
+	} else {
+		input_type = NCB_SOURCE_BURN;
+	}
+
+	return input_type;
+}
+
 static void
 update_progress_dialog_disc_type (NautilusBurnDrive        *drive,
 				  NautilusBurnerSourceData *burn_data,
@@ -1281,24 +1312,16 @@ update_progress_dialog_disc_type (NautilusBurnDrive        *drive,
 		}
 	};
 
-	if (! burn_data) {
-		input_type = 0;
-	} else if (burn_data->source_iso || burn_data->source_cue) {
-		input_type = 1;
-	} else if (burn_data->source_drive) {
-		input_type = 2;
-	} else {
-		input_type = 0;
-	}
+	input_type = get_input_type_from_source_data (burn_data);
 
 	if (drive->type == NAUTILUS_BURN_DRIVE_TYPE_FILE) {
-		output_type = 1;
+		output_type = NCB_OUTPUT_FILE;
 	} else {
 		switch (type) {
 		case NAUTILUS_BURN_MEDIA_TYPE_CD:
 		case NAUTILUS_BURN_MEDIA_TYPE_CDR:
 		case NAUTILUS_BURN_MEDIA_TYPE_CDRW:
-			output_type = 2;
+			output_type = NCB_OUTPUT_CD;
 			break;
 		case NAUTILUS_BURN_MEDIA_TYPE_DVD:
 		case NAUTILUS_BURN_MEDIA_TYPE_DVDR:
@@ -1307,11 +1330,11 @@ update_progress_dialog_disc_type (NautilusBurnDrive        *drive,
 		case NAUTILUS_BURN_MEDIA_TYPE_DVD_PLUS_R:
 		case NAUTILUS_BURN_MEDIA_TYPE_DVD_PLUS_RW:
 		case NAUTILUS_BURN_MEDIA_TYPE_DVD_PLUS_R_DL:
-			output_type = 3;
+			output_type = NCB_OUTPUT_DVD;
 			break;
 		case NAUTILUS_BURN_MEDIA_TYPE_UNKNOWN:
 		default:
-			output_type = 0;
+			output_type = NCB_OUTPUT_DEFAULT;
 			break;
 		}
 	}
@@ -1640,7 +1663,6 @@ static void
 refresh_dialog (GladeXML *xml)
 {
 	GtkWidget               *combobox;
-	GtkWidget               *eject_check;
 	GConfClient             *gc;
 	char                    *name;
 	int                      i, default_speed;
@@ -1683,9 +1705,6 @@ refresh_dialog (GladeXML *xml)
 		/* Disable speed if max speed < 1 */
 		gtk_widget_set_sensitive (combobox, max_speed_write > 0);
 
-		/* Disable eject for burn-to-iso */
-		eject_check = glade_xml_get_widget (xml, "eject_check");
-		gtk_widget_set_sensitive (eject_check, drive->type != NAUTILUS_BURN_DRIVE_TYPE_FILE);
 	}
 
 	/* for now assume equivalence between index in comboxbox and speed */
@@ -2109,7 +2128,6 @@ selection_dialog_response (GtkWidget                *dialog,
 		GtkWidget  *cancel_button;
 		GtkWidget  *entry;
 		GtkWidget  *speed_combobox;
-		GtkWidget  *eject_check;
 		GtkWidget  *dummy_check;
 		GtkWidget  *description_label;
 		gboolean    eject;
@@ -2125,7 +2143,6 @@ selection_dialog_response (GtkWidget                *dialog,
 		cancel_button      = glade_xml_get_widget (xml, "cancel_button");
 		description_label  = glade_xml_get_widget (xml, "progress_description_label");
 		entry              = glade_xml_get_widget (xml, "cdname_entry");
-		eject_check        = glade_xml_get_widget (xml, "eject_check");
 		speed_combobox     = glade_xml_get_widget (xml, "speed_combobox");
 		dummy_check        = glade_xml_get_widget (xml, "dummy_check");
 		progress_window    = glade_xml_get_widget (xml, "progress_window");
@@ -2140,7 +2157,10 @@ selection_dialog_response (GtkWidget                *dialog,
 		g_signal_connect (progress_window, "delete_event", G_CALLBACK (handle_delete_event), NULL);
 
 		label = gtk_entry_get_text (GTK_ENTRY (entry));
-		eject = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (eject_check));
+
+		/* eject all discs */
+		/* FIXME: make this gconf configurable? */
+		eject = TRUE;
 
 		speed = get_speed_selection (speed_combobox);
 
@@ -2251,6 +2271,23 @@ fill_selection_dialog (NautilusBurnerSourceData *burn_data)
 	return FALSE;
 }
 
+static void
+update_selection_dialog_source_type (NautilusBurnerSourceData *burn_data)
+{
+	GtkWidget *widget;
+	int        input_type;
+
+	input_type = get_input_type_from_source_data (burn_data);
+
+	if (NCB_SOURCE_DRIVE == input_type) {
+		widget = glade_xml_get_widget (xml, "cdr_dialog");
+		gtk_window_set_title (GTK_WINDOW (widget), _("Copy Disc"));
+
+		widget = glade_xml_get_widget (xml, "target_label");
+		gtk_label_set_text_with_mnemonic (GTK_LABEL (widget), _("Copy disc _to:"));
+	}
+}
+
 static gboolean
 create_selection_dialog (NautilusBurnerSourceData *burn_data)
 {
@@ -2286,6 +2323,8 @@ create_selection_dialog (NautilusBurnerSourceData *burn_data)
 	/* make insensitive until fill_dialog finishes */
 	gtk_widget_set_sensitive (dialog, FALSE);
 
+	update_selection_dialog_source_type (burn_data);
+
 	gtk_widget_show (dialog);
 
 	cursor = gdk_cursor_new (GDK_WATCH);
